#!/bin/sh

# Script to prepare Maemo 5 boot from /home (/dev/mmcblk0p2) partition
# Author: Leonid Yegoshin

if ! grep -q 'ubi0:rootfs / ubifs' /proc/mounts; then
    echo 'Please run this scipt on original Maemo 5 with 256MB root file system.'
    exit 1
fi

product=`osso-product-info -qOSSO_PRODUCT_RELEASE_VERSION`
prod=`echo $product | sed 's/-1.*$//' -`

if [ "x$prod" != "x20.2010.36-2" ]; then
    echo 'Please run this scipt on original Maemo 5 PR1.2 (20.2010.36-2)'
    exit 1
fi

# start work.

chksum=`/usr/bin/md5sum /sbin/preinit`
if [ "x$chksum" != "x10926aa4e68958c387bc08aacc39b4fa  /sbin/preinit" ]; then
    if [ "x$chksum" != "x8b030c7e22f4b58a644d2282144339a5  /sbin/preinit" ]; then
        echo "/sbin/preinit is a modified (non PR1.3 or PR1.3 + kernel-power) version. Stop"
        exit 1
    fi
fi

# fix bugs in /sbin/preinit

echo "Modifing /sbin/preinit..."

if [ -f /sbin/preinit.M32GBPR13-orig ]; then
    mv /sbin/preinit.M32GBPR13-orig /sbin/preinit
fi
mv /sbin/preinit /sbin/preinit.M32GBPR13-orig
cp /sbin/preinit.M32GBPR13-orig /sbin/preinit
sed -i '/attempting to use bootmenu/a\\     default_root="mmc"'  /sbin/preinit
sed -i '/if search_root_onmmc; then/a\\     root_mounted=0' /sbin/preinit


if [ ! -f /bootmenu.sh.M32GBPR12-orig ]; then
    mv /bootmenu.sh /bootmenu.sh.M32GBPR12-orig
fi

echo "Creating /bootmenu.sh..."

cat <<EOF >/bootmenu.sh
modprobe mmc_block
modprobe mmc_core
modprobe omap_hsmmc
modprobe mbcache
modprobe jbd
modprobe ext3
sleep 1
chmod 660 /dev/mmcblk*
mount -t ext3 -o noatime,nodiratime,commit=1,data=writeback /dev/mmcblk1p2 /mnt/new_root
EOF

chmod +x /bootmenu.sh

echo "Done. Booting with open keyboard will use root FS on eMMC partition 2."



