#!/bin/sh

# Script to prepare Maemo 5 root FS on /home (/dev/mmcblk0p2 = eMMC partition 2)
# Author: Leonid Yegoshin

if ! grep -q 'ubi0:rootfs / ubifs' /proc/mounts; then
    echo 'Please run this scipt on original Maemo 5 with 256MB root file system.'
    exit 1
fi

product=`osso-product-info -qOSSO_PRODUCT_RELEASE_VERSION`
prod=`echo $product | sed 's/-1.*$//' -`

if [ "x$prod" != "x20.2010.36-2" ]; then
    echo 'Please run this scipt on original Maemo 5 PR1.2 (20.2010.36-2)'
    exit 1
fi

# start work.

# remove old Maemo5 from /home first

echo "Remove old Maemo5 root files from /home before copying..."

(cd /home; rm -fr bin boot cdrom dev etc floppy initrd lib proc \
           root sbin srv sys syspart usr var mnt tmp media home)

# copy vital files

echo "Unmount /opt bindings (one error on /opt is expected)..."

MOUNTS=`mount | grep /opt | cut -d " " -f 1`
for MOUNT in $MOUNTS ;
do
	umount $MOUNT
done

echo "Start copying Maemo5 root file system to /home..."
echo "(device can be unresponsible around 10 minutes)"

mkdir /home/emmcroot

cp -a /bin /boot /cdrom /dev /etc /floppy /initrd /lib \
    /root /sbin /srv /usr /var       /home/emmcroot

echo "Copying done."
echo "Remount /opt back (error about / is expected)..."
start pymaemo-optify

# create dirs and links

echo "Create dirs..."

mkdir /home/emmcroot/proc
mkdir /home/emmcroot/sys
mkdir /home/emmcroot/syspart
mkdir -p /home/emmcroot/sys/kernel/debug
mkdir -p /home/emmcroot/mnt/initfs
mkdir /home/emmcroot/tmp
ln -s / /home/emmcroot/home
if [ ! -d /mnt/new_root ]; then
	mkdir /mnt/new_root
fi

echo "Edit a vital scripts on new root file system in /home partition..."

rm -f /home/emmcroot/etc/event.d/hildon-startup-progress
sed -i '/send_interface=/a\\        <allow send_type="method_call"/>' /home/emmcroot/etc/dbus-1/system.d/mce.conf

if [ -f /home/emmcroot/usr/sbin/maemo-optify-lib.sh ]; then
    sed -i -e "/test_home_mount\(\)/{n;a\\   return 0" -e "}" /home/emmcroot/usr/sbin/maemo-optify-lib.sh
    sed -i -e "/test_opt_mount\(\)/{n;a\\   return 0" -e "}" /home/emmcroot/usr/sbin/maemo-optify-lib.sh
fi

sed -i "/mount_home \&\& /s///" /home/emmcroot/etc/event.d/rcS-late

sed -i "/__home {/,/}/s/^/#/" /home/emmcroot/usr/lib/genfstab.awk

cat <<EOF >/home/emmcroot/etc/event.d/restart-mce
description "Restart mce to avoid a bug for loosing GPS in M32GB"
author "Leonid Yegoshin"

console output

start on started rcS-late

script
    sleep 20
    stop mce
    sleep 2
    start mce
end script
EOF

if [ -f /home/user/.config/tracker/tracker.cfg ]; then
    if ! grep -q '/mnt/initfs/' /home/user/.config/tracker/tracker.cfg; then
        sed -i '/NoWatchDirectory=/s?=?=/mnt/initfs/;?' /home/user/.config/tracker/tracker.cfg
	chown user:users /home/user/.config/tracker/tracker.cfg
    fi
fi

echo "Done: Maemo5 (20.2010.36-2) has been prepared in /home partition"




